@@ -5,9 +5,10 @@ import numpy as np
 
 from astropy.wcs.utils import skycoord_to_pixel, pixel_to_skycoord
 
-from ..core import PixelRegion, SkyRegion, Mask, BoundingBox, PixCoord
+from ..core import PixelRegion, SkyRegion, RegionMask, BoundingBox, PixCoord
 from .._geometry import polygonal_overlap_grid
 from .._geometry.pnpoly import points_in_polygon
+from ..core.attributes import OneDPix, OneDSky, RegionMeta, RegionVisual
 
 __all__ = ['PolygonPixelRegion', 'PolygonSkyRegion']
 
@@ -20,19 +21,48 @@ class PolygonPixelRegion(PixelRegion):
     ----------
     vertices : `~regions.PixCoord`
         The vertices of the polygon
+    meta : `~regions.RegionMeta` object, optional
+        A dictionary which stores the meta attributes of this region.
+    visual : `~regions.RegionVisual` object, optional
+        A dictionary which stores the visual meta attributes of this region.
+
+    Examples
+    --------
+
+    .. plot::
+        :include-source:
+
+        import numpy as np
+        from astropy.coordinates import Angle
+        from regions import PixCoord, PolygonPixelRegion
+        import matplotlib.pyplot as plt
+
+        x, y = [45, 45, 55, 60], [75, 70, 65, 75]
+        fig, ax = plt.subplots(1, 1)
+
+        vertices = PixCoord(x=x, y=y)
+        reg = PolygonPixelRegion(vertices=vertices)
+        patch = reg.as_artist(facecolor='none', edgecolor='red', lw=2)
+        ax.add_patch(patch)
+
+        plt.xlim(30, 80)
+        plt.ylim(50, 80)
+        ax.set_aspect('equal')
+        plt.show()
     """
 
-    def __init__(self, vertices, meta=None, visual=None):
-        self.vertices = PixCoord._validate(vertices, name='vertices', expected='not scalar')
-        self.meta = meta or {}
-        self.visual = visual or {}
-        self._repr_params = [('vertices', self.vertices)]
+    vertices = OneDPix('vertices')
 
-    # # TODO: needs to be implemented
-    # @property
-    # def area(self):
-    #     """Region area (float)."""
-    #     raise NotImplementedError
+    def __init__(self, vertices, meta=None, visual=None):
+        self.vertices = vertices
+        self.meta = meta or RegionMeta()
+        self.visual = visual or RegionVisual()
+        self._repr_params = ('vertices',)
+
+    @property
+    def area(self):
+        """Region area (float)."""
+        raise NotImplementedError
 
     def contains(self, pixcoord):
         pixcoord = PixCoord._validate(pixcoord, 'pixcoord')
@@ -43,18 +73,13 @@ class PolygonPixelRegion(PixelRegion):
 
         shape = x.shape
         mask = points_in_polygon(x.flatten(), y.flatten(), vx, vy).astype(bool)
-        return mask.reshape(shape)
-
-    def to_shapely(self):
-        # TODO: needs to be implemented
-        raise NotImplementedError
-
-    def to_sky(self, wcs, mode='local', tolerance=None):
-        if mode != 'local':
-            raise NotImplementedError
-        if tolerance is not None:
-            raise NotImplementedError
+        in_poly = mask.reshape(shape)
+        if self.meta.get('include', True):
+            return in_poly
+        else:
+            return np.logical_not(in_poly)
 
+    def to_sky(self, wcs):
         vertices_sky = pixel_to_skycoord(self.vertices.x, self.vertices.y, wcs)
         return PolygonSkyRegion(vertices=vertices_sky)
 
@@ -97,44 +122,58 @@ class PolygonPixelRegion(PixelRegion):
             nx, ny, vx, vy, use_exact, subpixels,
         )
 
-        return Mask(fraction, bbox=bbox)
+        return RegionMask(fraction, bbox=bbox)
 
-    def as_patch(self, **kwargs):
+    def as_artist(self, origin=(0, 0), **kwargs):
         """
         Matplotlib patch object for this region (`matplotlib.patches.Polygon`).
+
+        Parameters:
+        -----------
+        origin : array_like, optional
+            The ``(x, y)`` pixel position of the origin of the displayed image.
+            Default is (0, 0).
+        kwargs : `dict`
+            All keywords that a `~matplotlib.patches.Polygon` object accepts
+
+        Returns
+        -------
+        patch : `~matplotlib.patches.Polygon`
+            Matplotlib polygon patch
         """
         from matplotlib.patches import Polygon
-        xy = np.vstack([self.vertices.x, self.vertices.y]).transpose()
-        return Polygon(xy=xy, **kwargs)
+        xy = np.vstack([self.vertices.x - origin[0],
+                        self.vertices.y - origin[1]]).transpose()
+
+        mpl_params = self.mpl_properties_default('patch')
+        mpl_params.update(kwargs)
+
+        return Polygon(xy=xy, **mpl_params)
 
 
 class PolygonSkyRegion(SkyRegion):
     """
-    A polygon in sky coordinates.
+    A polygon defined using vertices in sky coordinates.
 
     Parameters
     ----------
     vertices : `~astropy.coordinates.SkyCoord`
         The vertices of the polygon
+    meta : `~regions.RegionMeta` object, optional
+        A dictionary which stores the meta attributes of this region.
+    visual : `~regions.RegionVisual` object, optional
+        A dictionary which stores the visual meta attributes of this region.
     """
 
+    vertices = OneDSky('vertices')
+
     def __init__(self, vertices, meta=None, visual=None):
-        # TODO: test that vertices is a 1D SkyCoord
         self.vertices = vertices
-        self.meta = meta or {}
-        self.visual = visual or {}
-        self._repr_params = [('vertices', self.vertices)]
-
-    def contains(self, skycoord):
-        # TODO: needs to be implemented
-        raise NotImplementedError
-
-    def to_pixel(self, wcs, mode='local', tolerance=None):
-        if mode != 'local':
-            raise NotImplementedError
-        if tolerance is not None:
-            raise NotImplementedError
+        self.meta = meta or RegionMeta()
+        self.visual = visual or RegionVisual()
+        self._repr_params = ('vertices',)
 
+    def to_pixel(self, wcs):
         x, y = skycoord_to_pixel(self.vertices, wcs)
         vertices_pix = PixCoord(x, y)
         return PolygonPixelRegion(vertices_pix)
